==> dokuwiki_0.0.20080505.orig.tar.gz: dokuwiki-2008-05-05/lib/plugins/plugin/lang/es/lang.php <==
<?php
/**
 * spanish language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Miguel Pagano <miguel.pagano@gmail.com>
 * @author Oscar M. Lage <r0sk10@gmail.com>
 * @author Gabriel Castillo <gch@pumas.ii.unam.mx>
 * @author oliver@samera.com.py
 */
$lang['menu']                  = 'Administración de Plugins';
$lang['download']              = 'Descargar e instalar un nuevo plugin';
$lang['manage']                = 'Plugins instalados';
$lang['btn_info']              = 'info';
$lang['btn_update']            = 'actualizar';
$lang['btn_delete']            = 'borrar';
$lang['btn_settings']          = 'configuraciones';
$lang['btn_download']          = 'Descargar';
$lang['btn_enable']            = 'Guardar';
$lang['url']                   = 'URL';
$lang['installed']             = 'Instalado:';
$lang['lastupdate']            = 'Última actualización:';
$lang['source']                = 'Origen:';
$lang['unknown']               = 'desconocido';
$lang['updating']              = 'Actualizando ...';
$lang['updated']               = 'El plugin %s ha sido actualizado exitosamente';
$lang['updates']               = 'Los siguientes plugins han sido actualizados exitosamente:';
$lang['update_none']           = 'No se encontraron actualizaciones.';
$lang['deleting']              = 'Eliminando ...';
$lang['deleted']               = 'El plugin %s ha sido eliminado.';
$lang['downloading']           = 'Descargando ...';
$lang['downloaded']            = 'El plugin %s ha sido descargado exitosamente';
$lang['downloads']             = 'Los siguientes plugins han sido descargados exitosamente:';
$lang['download_none']         = 'No se han encontrado plugins, o hubo algún problema durante la descarga o la instalación.';
$lang['plugin']                = 'Plugin:';
$lang['components']            = 'Componentes';
$lang['noinfo']                = 'Este plugin no devolvió información, puede ser inválido.';
$lang['name']                  = 'Nombre:';
$lang['date']                  = 'Fecha:';
$lang['type']                  = 'Tipo:';
$lang['desc']                  = 'Descripción:';
$lang['author']                = 'Autor:';
$lang['www']                   = 'Web:';
$lang['error']                 = 'Ha ocurrido un error desconocido.';
$lang['error_download']        = 'Incapaz de descargar el arhcivo del plugin: %s';
$lang['error_badurl']          = 'Se sospecha que la URL es incorrecta - incapaz de determinar el nombre del archivo a partir de la URL.';
$lang['error_dircreate']       = 'Incapaz de crear el directorio temporal para la descarga';
$lang['error_decompress']      = 'El administrador de plugin fue incapaz de descomprimir el fichero descargado esto puede ser por una descarga errónea, en ese caso debieras intentar nuevamente; o el formato de compresión es desconocido, en este caso deberas descargar e instalar el plugin manualmente.';
$lang['error_copy']            = 'Hubo un error al copiar el fichero mientras se intentaban instalar ficheros para el plugin <em>%s</em>: el disco puede estar lleno o los permisos del fichero pueden ser incorrectos. Esto puede haber terminado con una instalación parcial del plugin y haber dejado la instalación del wiki en una situación inestable';
$lang['error_delete']          = 'Hubo un error al intentar eliminar el plugin <em>%s</em>. La causa más probable es que no se cuente con los permisos necesarios en el fichero o en el directorio';

==> dokuwiki_0.0.20090214b.orig.tar.gz: dokuwiki-2009-02-14/lib/plugins/plugin/lang/es/lang.php <==
<?php
/**
 * spanish language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Miguel Pagano <miguel.pagano@gmail.com>
 * @author Oscar M. Lage <r0sk10@gmail.com>
 * @author Gabriel Castillo <gch@pumas.ii.unam.mx>
 * @author oliver@samera.com.py
 * @author Enrico Nicoletto <liverig@gmail.com>
 * @author Manuel Meco <manuel.meco@gmail.com>
 * @author VictorCastelan <victorcastelan@gmail.com>
 * @author Jordan Mero  hack.jord@gmail.com
 */
$lang['menu']                  = 'Administración de Plugins';
$lang['download']              = 'Descargar e instalar un nuevo plugin';
$lang['manage']                = 'Plugins instalados';
$lang['btn_info']              = 'info';
$lang['btn_update']            = 'actualizar';
$lang['btn_delete']            = 'borrar';
$lang['btn_settings']          = 'configuraciones';
$lang['btn_download']          = 'Descargar';
$lang['btn_enable']            = 'Guardar';
$lang['url']                   = 'URL';
$lang['installed']             = 'Instalado:';
$lang['lastupdate']            = 'Última actualización:';
$lang['source']                = 'Origen:';
$lang['unknown']               = 'desconocido';
$lang['updating']              = 'Actualizando ...';
$lang['updated']               = 'El plugin %s ha sido actualizado con exito';
$lang['updates']               = 'Los siguientes plugins han sido actualizados con exito:';
$lang['update_none']           = 'No se encontraron actualizaciones.';
$lang['deleting']              = 'Eliminando ...';
$lang['deleted']               = 'El plugin %s ha sido eliminado.';
$lang['downloading']           = 'Descargando ...';
$lang['downloaded']            = 'El plugin %s ha sido descargado con exito';
$lang['downloads']             = 'Los siguientes plugins han sido descargados con exito:';
$lang['download_none']         = 'No se han encontrado plugins, o hubo algún problema durante la descarga o la instalación.';
$lang['plugin']                = 'Plugin:';
$lang['components']            = 'Componentes';
$lang['noinfo']                = 'Este plugin no devolvió información, puede ser inválido.';
$lang['name']                  = 'Nombre:';
$lang['date']                  = 'Fecha:';
$lang['type']                  = 'Tipo:';
$lang['desc']                  = 'Descripción:';
$lang['author']                = 'Autor:';
$lang['www']                   = 'Web:';
$lang['error']                 = 'Ha ocurrido un error desconocido.';
$lang['error_download']        = 'Incapaz de descargar el archivo del plugin: %s';
$lang['error_badurl']          = 'Se sospecha que la URL es incorrecta - incapaz de determinar el nombre del archivo a partir de la URL.';
$lang['error_dircreate']       = 'Incapaz de crear el directorio temporal para la descarga';
$lang['error_decompress']      = 'El administrador de plugin fue incapaz de descomprimir el fichero descargado esto puede ser por una descarga errónea, en ese caso debieras intentar nuevamente; o el formato de compresión es desconocido, en este caso deberás descargar e instalar el plugin manualmente.';
$lang['error_copy']            = 'Hubo un error al copiar el fichero mientras se intentaban instalar ficheros para el plugin <em>%s</em>: el disco puede estar lleno o los permisos del fichero pueden ser incorrectos. Esto puede haber terminado con una instalación parcial del plugin y haber dejado la instalación del wiki en una situación inestable';
$lang['error_delete']          = 'Hubo un error al intentar eliminar el plugin <em>%s</em>. La causa más probable es que no se cuente con los permisos necesarios en el fichero o en el directorio';
$lang['enabled']               = 'Plugin %s habilitado.';
$lang['notenabled']            = 'Plugin %s no puede ser habilitado, verifica los permisos del archivo.';
$lang['disabled']              = 'Plugin %s desabilitado.';
$lang['notdisabled']           = 'Plugin %s no puede ser desabilitado, verifica los permisos de archivo.';
